@@ -3,9 +3,7 @@
 #'
 #' @description Let user paste link to a Google sheet then import the data.
 #'
-#' @param id Module's ID
-#' @param title Module's title, if \code{TRUE} use the default title,
-#'  use \code{NULL} for no title or a \code{shiny.tag} for a custom one.
+#' @inheritParams import-globalenv
 #'
 #' @eval doc_return_import()
 #'
@@ -16,7 +14,7 @@
 #' @importFrom shinyWidgets textInputIcon
 #' @importFrom htmltools tags tagList
 #'
-#' @example examples/googlesheets.R
+#' @example examples/from-googlesheets.R
 import_googlesheets_ui <- function(id, title = TRUE) {
 
   ns <- NS(id)
@@ -33,7 +31,7 @@ import_googlesheets_ui <- function(id, title = TRUE) {
     html_dependency_datamods(),
     title,
     tags$div(
-      class = "pull-right",
+      class = "pull-right float-right",
       help_popup(tagList(
         i18n("You can either use:"),
         tags$ul(
@@ -49,7 +47,7 @@ import_googlesheets_ui <- function(id, title = TRUE) {
     textInputIcon(
       inputId = ns("link"),
       label = i18n("Enter a shareable link to a GoogleSheet:"),
-      icon = icon("link"),
+      icon = phosphoricons::ph("link"),
       width = "100%"
     ),
     tags$div(
@@ -70,12 +68,7 @@ import_googlesheets_ui <- function(id, title = TRUE) {
 }
 
 
-#' @param btn_show_data Display or not a button to display data in a modal window if import is successful.
-#' @param trigger_return When to update selected data:
-#'  \code{"button"} (when user click on button) or
-#'  \code{"change"} (each time user select a dataset in the list).
-#' @param return_class Class of returned data: \code{data.frame}, \code{data.table} or \code{tbl_df} (tibble).
-#' @param reset A `reactive` function that when triggered resets the data.
+#' @inheritParams import_globalenv_server
 #'
 #' @export
 #'
@@ -84,7 +77,6 @@ import_googlesheets_ui <- function(id, title = TRUE) {
 #' @importFrom htmltools tags tagList
 #'
 #' @rdname import-googlesheets
-
 import_googlesheets_server <- function(id,
                                        btn_show_data = TRUE,
                                        trigger_return = c("button", "change"),
